@@ -555,6 +555,8 @@ class StandaloneStorageModel(StorageModel):
     time_interval_mins: t.Optional[int] = opt_field()
     ancillary_markets: t.Optional[AncillaryMarkets] = opt_field()
     ambient_temp: t.Optional[t.List[float]] = opt_field()
+    import_limit: t.Optional[t.List[float]] = opt_field()
+    export_limit: t.Optional[t.List[float]] = opt_field()
 
 
 @string_enum
@@ -573,6 +575,8 @@ class PVStorageModel(object):
     energy_prices: t.Union[AncillaryEnergyPrices, t.List[float]]
     enable_grid_charge_year: t.Optional[int] = opt_field()
     ancillary_markets: t.Optional[AncillaryMarkets] = opt_field()
+    import_limit: t.Optional[t.List[float]] = opt_field()
+    export_limit: t.Optional[t.List[float]] = opt_field()
 
 
 @string_enum
